Class: Diggit::Analysis Abstract
Overview
This class is abstract.
Subclass and override run and clean to implement a custom analysis class.
Base class for analyses. Diggit analyses are applied on each source that has been succesfully cloned. They can access the Diggit addons through the addons attribute.
Instance Attribute Summary collapse
-
#source ⇒ Source
The source to be analyzed.
Attributes inherited from Runnable
Attributes inherited from Plugin
Instance Method Summary collapse
-
#initialize(options) ⇒ Analysis
constructor
A new instance of Analysis.
Methods inherited from Runnable
#clean, require_addons, required_addons, #run
Methods inherited from Plugin
Constructor Details
#initialize(options) ⇒ Analysis
Returns a new instance of Analysis.
168 169 170 171 |
# File 'lib/dgit/plugins.rb', line 168 def initialize() super() @source = nil end |